==> ejc-settle-impl-3.0.0-20240617.053114-44-sources.jar: com/ejianc/business/settle/service/impl/SettlementCenterBudgetSubServiceImpl.java <==
package com.ejianc.business.settle.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.settle.bean.*;
import com.ejianc.business.settle.service.ISettlementCenterDcDrwgrpInfoService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.settle.mapper.SettlementCenterBudgetSubMapper;
import com.ejianc.business.settle.bean.SettlementCenterBudgetSubEntity;
import com.ejianc.business.settle.service.ISettlementCenterBudgetSubService;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 施工辅助工程
 * 
 * @author generator
 * 
 */
@Service("settlementCenterBudgetSubService")
public class SettlementCenterBudgetSubServiceImpl extends BaseServiceImpl<SettlementCenterBudgetSubMapper, SettlementCenterBudgetSubEntity> implements ISettlementCenterBudgetSubService{
    @Autowired
    private ISettlementCenterDcDrwgrpInfoService dcDrwgrpInfoService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Override
    public CommonResponse<JSONObject> excelImport(Long settlementCenterDcDrwgrpInfoId, HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();

        MultipartFile mf = null;
        List<SettlementCenterBudgetSubVO> successList = new ArrayList<>();
        List<SettlementCenterBudgetSubVO> errorList = new ArrayList<>();
        List<SettlementCenterBudgetSubVO> rtErrorList = new ArrayList<>();

        boolean isFailed = false;
        for (Map.Entry<String, MultipartFile> entry : fileMap.entrySet()) {
            mf = entry.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }

        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {

            List<List<String>> result = ExcelReader.readExcel(mf);
            if (result != null && result.size() > 0) {
                if (result.size() > 10000) {
                    return CommonResponse.error("信息超过10000条，请分批上传！");
                }
            }
            SettlementCenterDcDrwgrpInfoEntity drwgrpInfoEntity = dcDrwgrpInfoService.selectById(settlementCenterDcDrwgrpInfoId);
            for (int i = 1; i < result.size(); i++) {
                StringBuilder errmessage = new StringBuilder("");
                boolean flag = true;
                List<String> data = result.get(i);
                String index = data.get(0);
                String code = data.get(1);
                String name = data.get(2);
                String subNum = data.get(7);//统计工程量
                String settlementCenterSubMny = data.get(8);//统计产值(无税)
                String settlementCenterSubTaxMny = data.get(9);//统计产值(含税)
                String settlementCenterSubTax = data.get(10);//统计产值税额
                if (StringUtils.isNotEmpty(subNum)) {
                    SettlementCenterBudgetSubEntity one = this.getOne(
                            new QueryWrapper<SettlementCenterBudgetSubEntity>().lambda()
                                    .eq(SettlementCenterBudgetSubEntity::getBudgetId, drwgrpInfoEntity.getBudgeId())
                                    .eq(SettlementCenterBudgetSubEntity::getDetailIndex, index)
                                    .eq(SettlementCenterBudgetSubEntity::getSubCode, code)
                                    .eq(SettlementCenterBudgetSubEntity::getSubName, name)
                                    .eq(SettlementCenterBudgetSubEntity::getDcDrwgrpInfo,0)
                    );
                    if (one != null) {
                        if (StringUtils.isEmpty(subNum)){
                            flag = false;
                            errmessage.append("[统计工程量]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterSubMny)){
                            flag = false;
                            errmessage.append("[统计产值(无税)]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterSubTaxMny)){
                            flag = false;
                            errmessage.append("[统计产值(含税)]为空;");
                        }
                        if (StringUtils.isEmpty(settlementCenterSubTax)){
                            flag = false;
                            errmessage.append("[统计产值税额]为空;");
                        }
                        if (flag = false){
                            SettlementCenterBudgetSubVO vo = BeanMapper.map(one, SettlementCenterBudgetSubVO.class);
                            vo.setErrorMessage(errmessage.toString());
                            vo.setRowIndex(i);
                            errorList.add(vo);
                            continue;
                        }
                        one.setParentId(one.getId());
                        one.setId(IdWorker.getId());

                        one.setSettlementCenterSubNum(new BigDecimal(subNum));
                        one.setSettlementCenterSubTaxMny(new BigDecimal(settlementCenterSubTaxMny));
                        one.setSettlementCenterSubMny(new BigDecimal(settlementCenterSubMny));
                        one.setSettlementCenterSubTax(new BigDecimal(settlementCenterSubTax));
                        one.setDcDrwgrpInfo(drwgrpInfoEntity.getId());
                        SettlementCenterBudgetSubVO vo = BeanMapper.map(one, SettlementCenterBudgetSubVO.class);
                        successList.add(vo);
                    } else {
                        SettlementCenterBudgetSubVO vo = new SettlementCenterBudgetSubVO();
                        logger.info("第" + i + "行数据:" + StringUtils.join(data, ","));
                        vo.setRowIndex(i);
                        vo.setErrorMessage("明细未找到");
                        errorList.add(vo);
                    }

                }
            }


        }
        JSONObject json = new JSONObject();
        json.put("successList", successList);
        rtErrorList = errorList.stream().sorted(Comparator.comparing(SettlementCenterBudgetSubVO::getRowIndex)).collect(Collectors.toList());
        json.put("errorList", rtErrorList);
        CommonResponse<JSONObject> success = CommonResponse.success(json);
        return success;
    }
}

==> ejc-settle-impl-3.0.0-20240708.072402-71-sources.jar: com/ejianc/business/settle/service/impl/SettlementCenterBudgetSubServiceImpl.java <==
package com.ejianc.business.settle.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.ejianc.business.settle.bean.*;
import com.ejianc.business.settle.service.ISettlementCenterDcDrwgrpInfoService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.util.ExcelReader;
import com.ejianc.framework.core.util.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.settle.mapper.SettlementCenterBudgetSubMapper;
import com.ejianc.business.settle.bean.SettlementCenterBudgetSubEntity;
import com.ejianc.business.settle.service.ISettlementCenterBudgetSubService;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 施工辅助工程
 * 
 * @author generator
 * 
 */
@Service("settlementCenterBudgetSubService")
public class SettlementCenterBudgetSubServiceImpl extends BaseServiceImpl<SettlementCenterBudgetSubMapper, SettlementCenterBudgetSubEntity> implements ISettlementCenterBudgetSubService{
    @Autowired
    private ISettlementCenterDcDrwgrpInfoService dcDrwgrpInfoService;

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Override
    public CommonResponse<JSONObject> excelImport(Long settlementCenterDcDrwgrpInfoId, HttpServletRequest request) {
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();

        MultipartFile mf = null;
        List<SettlementCenterBudgetSubVO> successList = new ArrayList<>();
        List<SettlementCenterBudgetSubVO> errorList = new ArrayList<>();
        List<SettlementCenterBudgetSubVO> rtErrorList = new ArrayList<>();

        boolean isFailed = false;
        for (Map.Entry<String, MultipartFile> entry : fileMap.entrySet()) {
            mf = entry.getValue();
            String originalFileName = mf.getOriginalFilename();
            String extName = null;
            originalFileName = originalFileName.replaceAll("\\/|\\/|\\||:|\\?|\\*|\"|<|>|\\p{Cntrl}", "_");
            originalFileName.replaceAll("00.", "");
            extName = FileUtils.getFileExt(originalFileName, false);
            if (!"xls".equals(extName) && !"xlsx".equals(extName)) {
                isFailed = true;
                break;
            }
        }

        if (isFailed) {
            return CommonResponse.error("文件格式不合法");
        } else {

            List<List<String>> result = ExcelReader.readExcel(mf);
            if (result != null && result.size() > 0) {
                if (result.size() > 10000) {
                    return CommonResponse.error("信息超过10000条，请分批上传！");
                }
            }
            SettlementCenterDcDrwgrpInfoEntity drwgrpInfoEntity = dcDrwgrpInfoService.selectById(settlementCenterDcDrwgrpInfoId);
            for (int i = 1; i < result.size(); i++) {
                StringBuilder errmessage = new StringBuilder("");
                boolean flag = true;
                List<String> data = result.get(i);
                String index = data.get(0);
                String code = data.get(1);
                String name = data.get(2);
                String subNum = data.get(5);//统计工程量
                String memo = data.get(6);//备注
                if (StringUtils.isNotEmpty(subNum)) {
                    SettlementCenterBudgetSubEntity one = this.getOne(
                            new QueryWrapper<SettlementCenterBudgetSubEntity>().lambda()
                                    .eq(SettlementCenterBudgetSubEntity::getBudgetId, drwgrpInfoEntity.getBudgeId())
                                    .eq(SettlementCenterBudgetSubEntity::getDetailIndex, index)
                                    .eq(SettlementCenterBudgetSubEntity::getSubCode, code)
                                    .eq(SettlementCenterBudgetSubEntity::getSubName, name)
                                    .eq(SettlementCenterBudgetSubEntity::getDcDrwgrpInfo,0)
                    );
                    if (one != null) {
                        if (StringUtils.isEmpty(subNum)){
                            flag = false;
                            errmessage.append("[统计工程量]为空;");
                        }
                        if (flag = false){
                            SettlementCenterBudgetSubVO vo = BeanMapper.map(one, SettlementCenterBudgetSubVO.class);
                            vo.setErrorMessage(errmessage.toString());
                            vo.setRowIndex(i);
                            errorList.add(vo);
                            continue;
                        }
                        one.setParentId(one.getId());
                        one.setId(IdWorker.getId());

                        one.setSettlementCenterSubNum(new BigDecimal(subNum));
                        if (one.getSubTaxPrice() != null && !one.getSubTaxPrice().equals(BigDecimal.ZERO)) {
                            //统计产值(含税)
                            one.setSettlementCenterSubTaxMny(new BigDecimal(subNum).multiply(one.getSubTaxPrice()));
                        }else {
                            one.setSettlementCenterSubMny(BigDecimal.ZERO);
                        }
                        if (one.getSettlementCenterSubTaxMny() != null && !one.getSettlementCenterSubTaxMny().equals(BigDecimal.ZERO)
                                && one.getSubTaxRate() != null && !one.getSubTaxRate().equals(BigDecimal.ZERO)
                        ){
                            //统计产值(无税)
                            one.setSettlementCenterSubMny(one.getSettlementCenterSubTaxMny().divide(new BigDecimal(1).add(new BigDecimal(0.01).multiply(one.getSubTaxRate())),2, RoundingMode.HALF_DOWN));
                            //税额
                            one.setSettlementCenterSubTax(one.getSettlementCenterSubMny().multiply(one.getSubTaxRate()).multiply(new BigDecimal(0.01)));

                        }else {
                            one.setSettlementCenterSubMny(BigDecimal.ZERO);
                            one.setSettlementCenterSubTax(BigDecimal.ZERO);
                        }
                        one.setDcDrwgrpInfo(drwgrpInfoEntity.getId());
                        if (StringUtils.isNotEmpty(memo)){
                            one.setSubMemo(memo);
                        }
                        SettlementCenterBudgetSubVO vo = BeanMapper.map(one, SettlementCenterBudgetSubVO.class);
                        successList.add(vo);
                    } else {
                        SettlementCenterBudgetSubVO vo = new SettlementCenterBudgetSubVO();
                        logger.info("第" + i + "行数据:" + StringUtils.join(data, ","));
                        vo.setRowIndex(i);
                        vo.setErrorMessage("明细未找到");
                        errorList.add(vo);
                    }

                }
            }


        }
        JSONObject json = new JSONObject();
        json.put("successList", successList);
        rtErrorList = errorList.stream().sorted(Comparator.comparing(SettlementCenterBudgetSubVO::getRowIndex)).collect(Collectors.toList());
        json.put("errorList", rtErrorList);
        CommonResponse<JSONObject> success = CommonResponse.success(json);
        return success;
    }
}
